@@ -143,7 +143,7 @@ class AttributeLogger(Device):
 
     def generate_header(self):
         header_line = ["Datetime ({}, {})".format("str", "None"),
-                       "Timestamp ({}, {})".format(np.dtype("float").name, "None")]
+                       "Timestamp ({}, {})".format(np.dtype("float").name, "sec")]
 
         header_line += self.active_log_attributes
         return "# " + self.separator.join(header_line).replace("'", "").replace(", ", ",")
