@@ -50,7 +50,6 @@ class Device(Subject, YamlSerializable):
     response_timeout = 4000
     allow_reconnect = True
     session = None
-    # Maximum number of commands joined in one request
     max_command_retry = 0
     command_retry_count = 0
     push_commands_max = inf
@@ -95,7 +94,7 @@ class Device(Subject, YamlSerializable):
         self.connection_error = False
         self.response_error = False
         self.latency_buffer = []
-        self.init_timeout = self.init_time = time.time()
+        self.init_time = time.time()
         self.commands_buffer = deque()
         if kamzik3.session is not None and self.device_id not in kamzik3.session.devices:
             self.set_session(kamzik3.session)
@@ -135,6 +134,13 @@ class Device(Subject, YamlSerializable):
         self.create_attribute(ATTR_LAST_ERROR, readonly=True, description="Last device error exception")
 
     def create_attribute(self, name, group=None, **kwargs):
+        """
+        Use this function to create new attribute.
+        :param name: str
+        :param group: str
+        :param kwargs: dict
+        :return: Attribute
+        """
         attribute_path = name
         if group is not None:
             attribute_path = "{}.{}".format(group, attribute_path)
@@ -152,28 +158,15 @@ class Device(Subject, YamlSerializable):
             kamzik3.session.publisher.push_message(header, attribute)
         return attribute
 
-    def delete_attribute(self, name, group=None):
-        attribute_path = name
-        if group is not None:
-            attribute_path = "{}.{}".format(group, attribute_path)
-        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
-        if group is not None:
-            del self.attributes[group][name]
-        else:
-            del self.attributes[name]
-        if kamzik3.session.publisher is not None:
-            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_DELETE)
-            kamzik3.session.publisher.push_message(header, attribute_path)
-
-    def delete_attribute_group(self, group):
-        attribute_path = group
-        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
-        del self.attributes[group]
-        if kamzik3.session.publisher is not None:
-            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_GROUP_DELETE)
-            kamzik3.session.publisher.push_message(header, attribute_path)
-
     def add_attribute(self, name, attribute, group=None):
+        """
+        Use this function to add attribute to Device.
+        Set group parameter if You want attribute be in specific group.
+        :param name: str
+        :param attribute: Attribute
+        :param group: str
+        :return: Attribute
+        """
         attribute_list = [name]
         if group is None:
             self.attributes[name] = attribute
@@ -190,7 +183,47 @@ class Device(Subject, YamlSerializable):
             kamzik3.session.publisher.push_message(header, attribute)
         return attribute
 
+    def delete_attribute(self, name, group=None):
+        """
+        Delete specific attribute from group
+        :param name: str
+        :param group: str
+        :return: None
+        """
+        attribute_path = name
+        if group is not None:
+            attribute_path = "{}.{}".format(group, attribute_path)
+        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
+        if group is not None:
+            del self.attributes[group][name]
+        else:
+            del self.attributes[name]
+        if kamzik3.session.publisher is not None:
+            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_DELETE)
+            kamzik3.session.publisher.push_message(header, attribute_path)
+
+    def delete_attribute_group(self, group):
+        """
+        Delete all attributes including group
+        :param group: str
+        :return: None
+        """
+        attribute_path = group
+        attribute_id = "{}.{}.{}".format(self.device_id, TOKEN_ATTRIBUTE, attribute_path)
+        del self.attributes[group]
+        if kamzik3.session.publisher is not None:
+            header = "{}.{}".format(attribute_id, TOKEN_ATTRIBUTE_GROUP_DELETE)
+            kamzik3.session.publisher.push_message(header, attribute_path)
+
     def share_group(self, source_device, source_group, target_group, attribute_name_mask=None):
+        """
+        Share all attributes in group filtered by attribute_name_mask from source_device.
+        :param source_device: Device
+        :param source_group: str
+        :param target_group: str
+        :param attribute_name_mask: dict
+        :return: None
+        """
         if attribute_name_mask is None:
             attribute_name_mask = {}
         if source_group is not None:
@@ -878,6 +911,15 @@ class Device(Subject, YamlSerializable):
             Thread(target=_wait, args=[callback]).start()
 
     def wait_until_value_set(self, attribute, value, retry_timeout=1000, callback=None):
+        """
+        This function triggers callback or block until attribute is set to requested value.
+        There is retry_timeout of 1s until DeviceError is raised.
+        :param attribute:
+        :param value:
+        :param retry_timeout:
+        :param callback:
+        :return:
+        """
 
         def _wait(_callback=None):
             attribute_object = self.get_attribute(attribute)
@@ -908,13 +950,14 @@ class Device(Subject, YamlSerializable):
             return thread
 
     def is_alive(self):
+        """
+        Check if device is still connected
+        :return: bool
+        """
         if not self.connected or self.closing or self.response_error:
             return False
         time_diff = self.request_timestamp - self.response_timestamp
         if time_diff >= self.response_timeout * 1e-3:
-            print(self.device_id, time_diff, self.request_timestamp, self.response_timestamp,
-                  self.response_timeout * 1e-3)
-            print(len(self.commands_buffer), self.commands_buffer)
             self.handle_response_error(u"Response timeout")
             return False
         return True
