@@ -1,3 +1,4 @@
+import logging
 import os
 import time
 from collections import OrderedDict
@@ -20,6 +21,8 @@ class FileWorker(Worker, Process):
     def __init__(self, id, master_host, master_port, worker_host, worker_port=None, zmq_context=None):
         Process.__init__(self)
         Worker.__init__(self, id, master_host, master_port, zmq_context)
+        if not hasattr(self, "logger"):
+            self.logger = logging.getLogger("Device.{}".format(id))
         self.worker_host = worker_host
         self.worker_port = worker_port
 
@@ -64,6 +67,7 @@ class FileWorker(Worker, Process):
              str(self.worker_port).encode(), task_data[-1]])
         writer_address, _ = self.socket.recv_multipart()
         drive, source_file, remote_host, remote_port = task_data[5:9]
+        self.logger.info("Forwarding file {}:{}".format(drive.decode(), source_file.decode()))
         # Connect to remote host
         self.socket.connect("tcp://{}:{}".format(remote_host.decode(), remote_port.decode()))
         remote_address, _, message = self.socket.recv_multipart()
@@ -178,7 +182,7 @@ class FileWorker(Worker, Process):
         file_size = os.path.getsize(source_file)
         file_mod_time = os.path.getmtime(source_file)
         chunk_size = int(5e5)
-
+        self.logger.info("Pushing file {}".format(source_file))
         # Send file metadata to writer
         self.socket.send_multipart(
             [writer_address, MSG_EMPTY, source_file.encode(), str(file_size).encode(), str(file_mod_time).encode(),
@@ -245,6 +249,8 @@ class FileWorker(Worker, Process):
             self.socket.send_multipart(
                 [self.master_address, MSG_EMPTY, MSG_FORWARD, task_data[2], self.id, task_data[-1]])
         remote_host, remote_port, drive, source_file, dest_file, task_id = task_data[5:]
+        self.logger.info(
+            "Pulling file {}:{} and saving to {}".format(drive.decode(), source_file.decode(), dest_file.decode()))
         # Connect to remote File server
         self.socket.connect("tcp://{}:{}".format(remote_host.decode(), remote_port.decode()))
         # Get acknowledge response from remote File server
@@ -465,6 +471,7 @@ class DeviceFileServer(Device, BalancedServer, Thread):
             drive_meta = self.get_value(ATTR_DRIVES)[drive]
             source = drive_meta.get("source")
             cached, cache_path = self.is_cached(drive, input_dir, file_path)
+            self.logger.info("Syncing file {}:{}".format(drive, path))
             self.socket_backend.send_multipart(
                 [worker_id, MSG_EMPTY, worker_id, MSG_EMPTY, INSTRUCTION_SYNC, source.get_value(ATTR_HOST).encode(),
                  str(source.get_value(ATTR_PORT)).encode(),
@@ -498,6 +505,8 @@ class DeviceFileServer(Device, BalancedServer, Thread):
         self.clean_task_history()
         instruction = request[2]
         task_id = "T_{}".format(next(self.task_counter))
+        self.logger.info("Task {} added".format(task_id))
+
         self.create_attribute(ATTR_STATUS, task_id, default_value=STATUS_CONFIGURING, readonly=True)
         self.create_attribute(ATTR_STARTED_AT, task_id, default_value=time.time(), unit="sec", readonly=True,
                               default_type=np.float)
@@ -539,6 +548,7 @@ class DeviceFileServer(Device, BalancedServer, Thread):
         :return: None
         """
         if task_id in self.attributes:
+            self.logger.info("Task {} removed".format(task_id))
             self.delete_attribute_group(task_id)
 
     def set_task_progress(self, task_id, progress):
@@ -572,6 +582,7 @@ class DeviceFileServer(Device, BalancedServer, Thread):
         :param task_id:
         :return: None
         """
+        self.logger.info("Task {} aborted".format(task_id))
         self.set_value([task_id, ATTR_ABORTED], True)
         self.set_task_status(task_id, STATUS_IDLE)
 
@@ -595,6 +606,7 @@ class DeviceFileServer(Device, BalancedServer, Thread):
         Stop all running Tasks
         :return: None
         """
+        self.logger.info("Stop all tasks")
         for group in self.attributes.keys():
             if group == "General" or self.get_value([group, ATTR_STATUS]) != STATUS_BUSY:
                 continue
