@@ -5,7 +5,7 @@ import pandas
 
 from kamzik3.constants import STATUS_CONFIGURED
 from kamzik3.devices.device import Device
-from snippets.snippetsDecorators import expose_method
+from kamzik3.snippets.snippetsDecorators import expose_method
 
 
 class DeviceLogParser(Device):
@@ -70,7 +70,8 @@ class DeviceLogParser(Device):
         data_frame = pandas.concat(data_frames)
         if filter is not None:
             for filter_column, filter_range in filter.items():
-                data_frame = data_frame[(data_frame[filter_column] >= float(filter_range[0])) & (data_frame[filter_column] <= float(filter_range[1]))]
+                data_frame = data_frame[(data_frame[filter_column] >= float(filter_range[0])) & (
+                            data_frame[filter_column] <= float(filter_range[1]))]
                 # data_frame = data_frame[data_frame[filter_column] >= float(filter_range[0])]
                 # data_frame = data_frame[data_frame[filter_column] <= float(filter_range[1])]
 
