@@ -3,9 +3,7 @@ import re
 import time
 from threading import Thread
 
-import PyTango
 import numpy as np
-from PyTango import DeviceProxy
 
 from kamzik3 import DeviceError
 from kamzik3.constants import *
@@ -13,6 +11,12 @@ from kamzik3.devices.device import Device
 from kamzik3.snippets.snippetsDecorators import expose_method
 from kamzik3.snippets.snippetsUnits import device_units
 
+try:
+    import PyTango
+    from PyTango import DeviceProxy
+except ImportError:
+    raise DeviceError("PyTango import error!")
+
 ATTR_TANGO_STATUS = "Tango status"
 
 """ Example of yaml configuration
