@@ -32,11 +32,22 @@ class DeviceVirtualDirectory(DeviceFileServer):
         self.logger.info(u"Device configuration took {} sec.".format(time.time() - start_at))
 
     def _set_drives(self, drives):
+        """
+        Initiate drives for current virtual directory.
+        :param drives: dict
+        :return: None
+        """
         for value in drives.values():
             value["path"] = os.path.normpath(value["path"])
         self.set_value(ATTR_DRIVES, drives)
 
     def _check_allowed_path(self, drive, path):
+        """
+        Check if requested path on drive is actually allowed and exists
+        :param drive: str
+        :param path: str
+        :return: bool
+        """
         drives = self.get_value(ATTR_DRIVES)
 
         if drive not in drives:
@@ -57,6 +68,14 @@ class DeviceVirtualDirectory(DeviceFileServer):
 
     @expose_method({"drive": "Drive", "input_dir": "Path to the directory", "file_filter": "Regexp filter"})
     def get_dir_content(self, drive, input_dir, file_filter=None):
+        """
+        Get all files, dirs and metadata (modtime, filesize) within input_dir and drive.
+        You can set file_filter regexp to filter out file names.
+        :param drive: str
+        :param input_dir:  str
+        :param file_filter: regexp str
+        :return: str, list, list, list, list
+        """
         self._check_allowed_path(drive, input_dir)
         drive_meta = self.get_value(ATTR_DRIVES)[drive]
         source = drive_meta.get("source", LOCAL_FILESYSTEM)
@@ -83,6 +102,14 @@ class DeviceVirtualDirectory(DeviceFileServer):
 
     @expose_method({"drive": "Drive", "input_dir": "Path to the directory", "file_name": "File name"})
     def get_meta_hash(self, drive, input_dir, file_name):
+        """
+        Get hash of device_id+drive+file_path this should ensure unique hash for any filepath.
+        Return value is used as a path for cached file.
+        :param drive: str
+        :param input_dir: str
+        :param file_name: str
+        :return: str
+        """
         self._check_allowed_path(drive, input_dir)
         drive_meta = self.get_value(ATTR_DRIVES)[drive]
         source = drive_meta.get("source", LOCAL_FILESYSTEM)
@@ -95,6 +122,13 @@ class DeviceVirtualDirectory(DeviceFileServer):
 
     @expose_method({"drive": "Drive", "input_dir": "Path to the directory", "file_name": "File name"})
     def get_local_path(self, drive, input_dir, file_name):
+        """
+        Get local path to either cache or file on local fs
+        :param drive: str
+        :param input_dir: str
+        :param file_name: str
+        :return: tuple (bool, str)
+        """
         self._check_allowed_path(drive, input_dir)
         drive_meta = self.get_value(ATTR_DRIVES)[drive]
         source = drive_meta.get("source", LOCAL_FILESYSTEM)
@@ -108,6 +142,13 @@ class DeviceVirtualDirectory(DeviceFileServer):
             return False, None
 
     def is_cached(self, drive, input_dir, file_name):
+        """
+        Check if path on drive from input_dir is cached
+        :param drive: str
+        :param input_dir: str
+        :param file_name: str
+        :return: tuple (bool, path_hash)
+        """
         cache_directory = kamzik3.session.get_value(ATTR_CACHE_DIRECTORY)
         path_hash, file_size, file_mod_time = self.get_meta_hash(drive, input_dir, file_name)
         path_hash = os.path.join(cache_directory, path_hash)
@@ -122,7 +163,7 @@ class DeviceVirtualDirectory(DeviceFileServer):
         """
         Get through all files and get real drive / path combination.
         :param files: list of files
-        :return:
+        :return: tuple (list of files, metadata)
         """
         prepared_files = []
         metadata = dict()
@@ -139,13 +180,11 @@ class DeviceVirtualDirectory(DeviceFileServer):
 
     def sync_files(self, requested_files):
         """
-        Request all files from fileserver
+        Request files from fileserver
         :param requested_files:
-        :return:
+        :return: list
         """
-        # requested_files = set([tuple(f) for f in requested_files])
         sync_parts = [INSTRUCTION_SYNC, str(len(requested_files)).encode()]
-        # sync_parts = [x for x in requested_files if x not in sync_parts]
         for drive, file_path in requested_files:
             sync_parts += [drive.encode(), file_path.encode()]
         self.frontend_connector.send_multipart(sync_parts)
@@ -154,6 +193,12 @@ class DeviceVirtualDirectory(DeviceFileServer):
 
     @expose_method({"drive": "Drive", "path": "Path to the file"})
     def on_fs(self, drive, path):
+        """
+        Check if file path from drive exists on local drive.
+        :param drive: str
+        :param path: str
+        :return: bool
+        """
         self._check_allowed_path(drive, path)
         drive_meta = self.get_value(ATTR_DRIVES)[drive]
         source = drive_meta.get("source", LOCAL_FILESYSTEM)
