@@ -1,6 +1,5 @@
 import pyqtgraph as pg
 from PyQt5.QtCore import pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QFont
 from PyQt5.QtWidgets import QMdiSubWindow
 
 from kamzik3.snippets.snippetsUnits import get_scaled_time_duration
@@ -49,6 +48,7 @@ class LogPlotView(pg.PlotWidget):
         self.setLabel(u"bottom", kwargs.get("bottom_label", None))
         self.setTitle(kwargs.get("top_label", None))
         self.showGrid(x=True, y=True, alpha=0.1)
+        self.getAxis("left").enableAutoSIPrefix(False)
         self.addItem(self.value_curve)
         self.sig_repaint.connect(self.slot_set_data)
 
