@@ -52,6 +52,7 @@ class LogView(Ui_Form, DeviceWidget):
         :return:
         """
         try:
+            self.logger.info("Opening {}, append: {}, refresh: {}, filter: {}".format(path, append, refresh, filter))
             padas_dt = self.device.parse(path=path, format="mag_log", filter=filter)
             if append:
                 self.pandas_dt = self.pandas_dt.append(padas_dt)
@@ -112,7 +113,7 @@ class LogView(Ui_Form, DeviceWidget):
         window.setWidget(widget)
         window.master = master
         y = self.pandas_dt[id].values
-        x = self.pandas_dt["Timestamp (None)"].values
+        x = self.pandas_dt["Timestamp (sec)"].values
         widget.slot_set_data(x=x, y=y)
 
         return window
@@ -287,13 +288,15 @@ class LogView(Ui_Form, DeviceWidget):
         :return: None
         """
         if flag:
+            self.logger.info("View set to zoom mode.")
             self.view_mode = MODE_ZOOM
             self.tabs_view_tools.setCurrentIndex(0)
             current_sub_window = self.mdi_area.currentSubWindow()
+            if current_sub_window is None:
+                return
             zoom_master = self.input_master_row.currentText()
             if current_sub_window is not None:
                 zoom_master = current_sub_window.id
-
             self.input_master_row.blockSignals(True)
             self.input_master_row.setCurrentText(zoom_master)
             self.input_master_row.blockSignals(False)
@@ -308,6 +311,7 @@ class LogView(Ui_Form, DeviceWidget):
         :return: None
         """
         if flag:
+            self.logger.info("View set to list mode.")
             self.view_mode = MODE_LIST
             if self.master_window is not None:
                 mater_window_id = self.master_window.id
@@ -339,6 +343,7 @@ class LogView(Ui_Form, DeviceWidget):
         :param rows: int
         :return: None
         """
+        self.logger.info("Maximum number of rows was set to: {}".format(rows))
         self.input_header_items.selectionModel().max_selected_rows = rows
 
     @pyqtSlot(str)
@@ -377,6 +382,7 @@ class LogView(Ui_Form, DeviceWidget):
         Reset zoom of Master plot.
         :return:
         """
+        self.logger.info("Resetting zoom.")
         if self.master_window is not None:
             self.master_window.widget().reset_zoom()
 
@@ -386,6 +392,7 @@ class LogView(Ui_Form, DeviceWidget):
         Reset zoom of Master plot.
         :return:
         """
+        self.logger.info("Resetting all plots, zoom and views.")
         self.slot_set_list_mode(True)
         self.master_window = None
         self.last_zoom_region = None
@@ -393,6 +400,7 @@ class LogView(Ui_Form, DeviceWidget):
         self.button_list_view.click()
         self.pushButton.click()
         self.pushButton_2.click()
+        self.input_master_row.clear()
 
     @pyqtSlot()
     def slot_selection_changed(self, row_model_index=None):
@@ -482,6 +490,12 @@ class LogView(Ui_Form, DeviceWidget):
             self.tile_sub_windows()
 
     def slot_export_to_pdf(self):
+        if len(self.mdi_area.subWindowList()) == 0:
+            error_msg = "Export error: {}".format("Please select at least one plot to export.")
+            self.logger.error(error_msg)
+            show_error_message(error_msg, self)
+            return
+
         plot_width, plot_height = self.input_plot_width.value(), self.input_plot_height.value()
         options = QFileDialog.Options()
         options |= QFileDialog.DontUseNativeDialog
@@ -490,6 +504,7 @@ class LogView(Ui_Form, DeviceWidget):
                                                    filter=extension_filter, initialFilter=extension_filter,
                                                    options=options)
         if file_path != "":
+            self.logger.info("Exporting plots to {} using w: {}px, h: {}px".format(file_path, plot_width, plot_height))
             parts = []
             cache_dir = kamzik3.session.get_value(ATTR_CACHE_DIRECTORY)
             for index, window in enumerate(reversed(self.mdi_area.subWindowList())):
@@ -513,4 +528,6 @@ class LogView(Ui_Form, DeviceWidget):
                     plot_width += abs(plot_width - float(pw))
                     plot_height += abs(plot_height - float(ph))
                 except Exception as e:
-                    show_error_message("Export error: {}".format(e), self)
+                    error_msg = "Export error: {}".format(e)
+                    self.logger.error(error_msg)
+                    show_error_message(error_msg, self)
