@@ -8,8 +8,7 @@ from threading import Thread, Event, Lock
 import numpy
 
 from kamzik3.constants import *
-from kamzik3.snippets.snippetsTimer import CallbackTimer
-from kamzik3.snippets.snippetsTimer import PreciseCallbackTimer
+from kamzik3.snippets.snippetsTimer import PreciseCallbackTimer, CallbackTimer
 
 
 # TODO: Look for possibility to use event loop
@@ -113,7 +112,9 @@ class DevicePoller(PreciseCallbackTimer):
     def __init__(self, interval=5):
         self.interval = interval
         self.commands_buffer = {}
-        self.lock = Lock()
+        self.poll_commands_buffer = {}
+        self.poll_lock = Lock()
+        self.command_lock = Lock()
         self.logger = logging.getLogger(u"Console.DevicePoller")
         self.polling_schedule = OrderedDict()
         self.schedule = []
@@ -125,19 +126,28 @@ class DevicePoller(PreciseCallbackTimer):
         PreciseCallbackTimer.run(self)
 
     def timer_tick(self):
-        with self.lock:
-            for pollAt in self.schedule:
-                if self.schedule_at % pollAt == 0:
-                    for device, attributes in self.polling_schedule[pollAt].items():
-                        if device.accepting_commands() and device in self.commands_buffer:
-                            self.commands_buffer[device] += attributes
-
+        with self.command_lock:
+            # Send pending commands
             for device, commands in self.commands_buffer.items():
                 if commands and device.accepting_commands():
                     self.commands_buffer[device] = device.send_command(commands)
-                    device.set_value(ATTR_BUFFERED_COMMANDS, len(self.commands_buffer[device]))
 
-            self.schedule_at += self.interval
+        with self.poll_lock:
+            # Prepare polling commands
+            for pollAt in self.schedule:
+                if self.schedule_at % pollAt == 0:
+                    for device, attributes in self.polling_schedule[pollAt].items():
+                        if device.accepting_commands() and device in self.poll_commands_buffer:
+                            self.poll_commands_buffer[device] += attributes
+
+        with self.poll_lock:
+            # Send polling commands
+            for device, commands in self.poll_commands_buffer.items():
+                if commands and device.accepting_commands():
+                    self.poll_commands_buffer[device] = device.send_command(commands)
+                    device.set_value(ATTR_BUFFERED_COMMANDS, len(self.poll_commands_buffer[device]))
+
+        self.schedule_at += self.interval
 
     def set_timeout(self, timeout):
         PreciseCallbackTimer.set_timeout(self, timeout)
@@ -149,13 +159,13 @@ class DevicePoller(PreciseCallbackTimer):
         PreciseCallbackTimer.stop(self)
 
     def add(self, device, attribute, poll_at, callback=None, returning=True, force_add=False):
-        with self.lock:
+        with self.poll_lock:
             if poll_at not in self.polling_schedule:
                 self.polling_schedule[poll_at] = OrderedDict()
             if device not in self.polling_schedule[poll_at]:
                 self.polling_schedule[poll_at][device] = []
-            if device not in self.commands_buffer:
-                self.commands_buffer[device] = []
+            if device not in self.poll_commands_buffer:
+                self.poll_commands_buffer[device] = []
 
             polling_quadruplet = (attribute, None, callback, returning)
             if force_add or polling_quadruplet not in self.polling_schedule[poll_at][device]:
@@ -164,12 +174,12 @@ class DevicePoller(PreciseCallbackTimer):
             self.schedule = sorted(self.polling_schedule.keys())
 
     def remove(self, device, attribute, poll_at, callback=None, returning=True):
-        with self.lock:
+        with self.poll_lock:
             try:
                 self.polling_schedule[poll_at][device].remove((attribute, None, callback, returning))
                 if len(self.polling_schedule[poll_at][device]) == 0:
                     del self.polling_schedule[poll_at][device]
-                    del self.commands_buffer[device]
+                    del self.poll_commands_buffer[device]
                 if len(self.polling_schedule[poll_at]) == 0:
                     del self.polling_schedule[poll_at]
 
@@ -178,9 +188,9 @@ class DevicePoller(PreciseCallbackTimer):
                 pass
 
     def stop_polling(self, device):
-        with self.lock:
-            if device in self.commands_buffer:
-                del self.commands_buffer[device]
+        with self.poll_lock:
+            if device in self.poll_commands_buffer:
+                del self.poll_commands_buffer[device]
             for polledDevices in self.polling_schedule.values():
                 try:
                     if device in polledDevices:
@@ -189,20 +199,18 @@ class DevicePoller(PreciseCallbackTimer):
                     pass  # device is no longer within polled devices
 
     def prepare_command(self, device, command):
-        with self.lock:
+        with self.command_lock:
             try:
                 self.commands_buffer[device].append(command)
             except KeyError:
-                self.commands_buffer[device] = []
-                self.commands_buffer[device].append(command)
+                self.commands_buffer[device] = [command]
 
     def prepend_command(self, device, command):
-        with self.lock:
+        with self.command_lock:
             try:
                 self.commands_buffer[device].insert(0, command)
             except KeyError:
-                self.commands_buffer[device] = []
-                self.commands_buffer[device].insert(0, command)
+                self.commands_buffer[device] = [command]
 
 
 class DeviceAsyncoreLoop(Thread):
