@@ -1,7 +1,7 @@
 import datetime
 import math
 
-from pint import UndefinedUnitError, DimensionalityError
+from pint import UndefinedUnitError
 
 from kamzik3 import units
 from kamzik3.constants import *
@@ -9,7 +9,7 @@ from kamzik3.constants import *
 
 def _base_unit(unit):
     try:
-        prefix, base_unit, suffix = units.parse_unit_name(unit)[0]
+        prefix, base_unit, suffix = tuple(units.parse_unit_name(unit))[0]
     except (IndexError, UndefinedUnitError, AttributeError, StopIteration):
         prefix, base_unit, suffix = None, unit, None
     return prefix, base_unit, suffix
@@ -97,30 +97,35 @@ def device_units(device, attribute, value):
 MAX_SECONDS = 3.154e+9
 
 
-def get_scaled_time_duration(seconds):
+def get_scaled_time_duration(seconds, short=False):
     if seconds < 0:
         return
     if seconds >= MAX_SECONDS:
         return "> 100 Years"
 
+    if not short:
+        sec, msec, min, day, hour, month, year = "Sec", "MSec", "Min", "Day", "Hour", "Month", "Year"
+    else:
+        sec, msec, min, day, hour, month, year = "s", "ms", "m", "D", "h", "M", "Y"
+
     d = datetime.datetime(1, 1, 1) + datetime.timedelta(seconds=seconds)
 
     if seconds < 60:
         milliseconds = int(d.microsecond / 1000)
         if milliseconds > 0:
-            time_estimate = "{} Sec {} MSec".format(d.second, milliseconds)
+            time_estimate = "{} {} {} {}".format(d.second, sec, milliseconds, msec)
         else:
-            time_estimate = "{} Sec".format(d.second)
+            time_estimate = "{} {}".format(d.second, sec)
     elif 60 <= seconds < 3600:
-        time_estimate = "{} Min {} Sec".format(d.minute, d.second)
+        time_estimate = "{} {} {} {}".format(d.minute, min, d.second, sec)
     elif 3600 <= seconds < 24 * 3600:
-        time_estimate = "{} Hour {} Min".format(d.hour, d.minute)
+        time_estimate = "{} {} {} {}".format(d.hour, hour, d.minute, min)
     elif 24 * 3600 <= seconds < 24 * 3600 * 28:
-        time_estimate = "{} Day {} Hour {} Min".format(d.day - 1, d.hour, d.minute)
+        time_estimate = "{} {} {} {} {} {}".format(d.day - 1, day, d.hour, hour, d.minute, min)
     elif 24 * 3600 * 28 <= seconds < 24 * 3600 * 28 * 12:
-        time_estimate = "{} Month {} Day {} Hour".format(d.month - 1, d.day, d.hour)
+        time_estimate = "{} {} {} {} {} {}".format(d.month - 1, month, d.day, day, d.hour, hour)
     else:
-        time_estimate = "{} Year {} Month {} Day".format(d.year - 1, d.month, d.day)
+        time_estimate = "{} {} {} {} {} {}".format(d.year - 1, year, d.month, month, d.day, day)
 
     return time_estimate
 
@@ -130,3 +135,42 @@ def seconds_to_datetime(seconds):
         seconds = MAX_SECONDS
 
     return datetime.datetime.fromtimestamp(seconds).strftime("%d.%m.%Y %H:%M:%S")
+
+
+def get_printable_size(byte_size):
+    """
+    A bit is the smallest unit, it's either 0 or 1
+    1 byte = 1 octet = 8 bits
+    1 kB = 1 kilobyte = 1000 bytes = 10^3 bytes
+    1 KiB = 1 kibibyte = 1024 bytes = 2^10 bytes
+    1 KB = 1 kibibyte OR kilobyte ~= 1024 bytes ~= 2^10 bytes (it usually means 1024 bytes but sometimes it's 1000... ask the sysadmin ;) )
+    1 kb = 1 kilobits = 1000 bits (this notation should not be used, as it is very confusing)
+    1 ko = 1 kilooctet = 1000 octets = 1000 bytes = 1 kB
+
+    Also Kb seems to be a mix of KB and kb, again it depends on context.
+
+    In linux, a byte (B) is composed by a sequence of bits (b). One byte has 256 possible values.
+
+    More info : http://www.linfo.org/byte.html
+    """
+    BASE_SIZE = 1024.00
+    MEASURE = ["B", "KB", "MB", "GB", "TB", "PB"]
+
+    def _fix_size(size, size_index):
+        if not size:
+            return "0"
+        elif size_index == 0:
+            return str(size)
+        else:
+            return "{:.3f}".format(size)
+
+    current_size = byte_size
+    size_index = 0
+
+    while current_size >= BASE_SIZE and len(MEASURE) != size_index:
+        current_size = current_size / BASE_SIZE
+        size_index = size_index + 1
+
+    size = _fix_size(current_size, size_index)
+    measure = MEASURE[size_index]
+    return size + " " + measure
